@@ -40,7 +40,7 @@ from ExcelDataDriver.Keywords.CoreExcelKeywords import CoreExcelKeywords
 from ExcelDataDriver.Config.CaptureScreenShotOption import CaptureScreenShotOption
 
 
-__version__ = '1.2.2'
+__version__ = '1.2.3'
 
 
 class ExcelDataDriver:
@@ -301,6 +301,10 @@ class ExcelDataDriver:
     # Public Utility Keywords
     #
     #############################################
+    @keyword
+    def update_test_property(self, property_name, property_value):
+        self.excelTestDataService.update_test_property(property_name, property_value)
+
     @keyword
     def update_test_result(self, status, log_message=None, screenshot=None):
         """
@@ -466,6 +470,17 @@ class ExcelDataDriver:
         """
         return self.excelTestDataService.get_test_data_property(property_name)
 
+    @keyword
+    def update_test_data_property(self, property_name, property_value):
+        """
+        Update test data property
+
+        Arguments:
+            | property_name  | Test data property name should be lower case                    |
+            | property_value | Test data value                                                 |
+        """
+        return self.excelTestDataService.update_test_property(property_name, property_value)
+
     @keyword
     def verify_update_data_property(self, property_name, data_type, allow_none=True, *data_list):
         """
